numina.util — Generic utilities — Numina 0.20.dev0 documentation

# `numina.util` — Generic utilities

## `numina.util.flow` — Flow objects

exception `numina.util.flow.` `FlowError`

  Error base class for flows.

class `numina.util.flow.` `MixerFlow`(table)

class `numina.util.flow.` `ParallelFlow`(nodeseq)

  A flow where Nodes are executed in parallel.

class `numina.util.flow.` `SerialFlow`(nodeseq)

  A flow where Nodes are executed sequentially.

## `numina.util.objimport` — Import objects

Import objects by name

`numina.util.objimport.` `import_object`(path)

  Import an object given its fully qualified name.